@@ -253,7 +253,10 @@ class Site(collections.Mapping, collections.Hashable):
                 d['occu'] = occu
                 species_list.append(d)
                 species_list.append({'element': spec.symbol, 'occu': occu, 'oxidation_state': spec.oxi_state})
-        return {'name': self.species_string, 'species': species_list, 'occu': occu, 'xyz':[float(c) for c in self._coords], 'properties': self._properties}
+        d = {'name': self.species_string, 'species': species_list, 'occu': occu, 'xyz':[float(c) for c in self._coords], 'properties': self._properties}
+        d['module'] = self.__class__.__module__
+        d['class'] = self.__class__.__name__
+        return d
 
     @staticmethod
     def from_dict(d):
@@ -357,7 +360,7 @@ class PeriodicSite(Site):
         """
         if self.lattice != other.lattice:
             return False
-        frac_diff = abs(self._fcoords - other._fcoords) % 1
+        frac_diff = abs(np.array(self._fcoords) - np.array(other._fcoords)) % 1
         frac_diff = [abs(a) < tolerance or abs(a) > 1 - tolerance for a in frac_diff]
         return  all(frac_diff)
 
@@ -510,11 +513,14 @@ class PeriodicSite(Site):
                 d = spec.to_dict
                 d['occu'] = occu
                 species_list.append(d)
-        return {'label': self.species_string, 'species': species_list,
-                'occu': occu, 'xyz':[float(c) for c in self._coords],
-                'abc':[float(c) for c in self._fcoords],
-                'lattice': self._lattice.to_dict,
-                'properties': self._properties}
+        d = {'label': self.species_string, 'species': species_list,
+             'occu': occu, 'xyz':[float(c) for c in self._coords],
+             'abc':[float(c) for c in self._fcoords],
+             'lattice': self._lattice.to_dict,
+             'properties': self._properties}
+        d['module'] = self.__class__.__module__
+        d['class'] = self.__class__.__name__
+        return d
 
     @staticmethod
     def from_dict(d, lattice=None):
@@ -1102,6 +1108,8 @@ class Structure(SiteCollection):
         Json-serializable dict representation of Structure
         """
         d = {}
+        d['module'] = self.__class__.__module__
+        d['class'] = self.__class__.__name__
         d['lattice'] = self._lattice.to_dict
         d['sites'] = [site.to_dict for site in self]
         return d
@@ -1214,6 +1222,8 @@ class Molecule(SiteCollection):
         Json-serializable dict representation of Molecule
         """
         d = {}
+        d['module'] = self.__class__.__module__
+        d['class'] = self.__class__.__name__
         d['sites'] = [site.to_dict for site in self]
         return d
 
@@ -1780,6 +1790,22 @@ class Composition (collections.Mapping, collections.Hashable):
         c = Composition.from_formula(reduced_formula)
         return c.to_dict
 
+    @property
+    def to_data_dict(self):
+        '''
+        Returns a dict with many composition-related properties.
+        
+        Returns:
+            A dict with many keys and values relating to Composition/Formula
+        '''
+        d = {}
+        d['reduced_cell_composition'] = self.to_reduced_dict
+        d['unit_cell_composition'] = self.to_dict
+        d['reduced_cell_formula'] = self.reduced_formula
+        d['elements'] = self.to_dict.keys()
+        d['nelements'] = len(self.to_dict.keys())
+        return d
+
     @staticmethod
     def ranked_compositions_from_indeterminate_formula(fuzzy_formula, lock_if_strict=True):
         '''
