@@ -266,10 +266,12 @@ class StructureEditor(StructureModifier):
 
     def perturb_structure(self, distance=0.1):
         '''
-        performs a random perturbation of the sites in a structure to break symmetries
+        Performs a random perturbation of the sites in a structure to break
+        symmetries.
         
         Args:
-            distance: distance by which to perturb each site
+            distance:
+                distance in angstroms by which to perturb each site.
         '''
         for i in range(len(self._sites)):
             vector = np.random.rand(3)
@@ -304,10 +306,11 @@ class SupercellMaker(StructureModifier):
             structure:
                 pymatgen.core.structure Structure object.
             scaling_matrix:
-                a matrix of transforming the lattice vectors. Defaults to the identity matrix.
-                Has to be all integers. e.g., [[2,1,0],[0,3,0],[0,0,1]] generates a new structure
-                with lattice vectors a' = 2a + b, b' = 3b, c' = c where a, b, and c are the lattice 
-                vectors of the original structure. 
+                a matrix of transforming the lattice vectors. Defaults to the
+                identity matrix. Has to be all integers. e.g.,
+                [[2,1,0],[0,3,0],[0,0,1]] generates a new structure with
+                lattice vectors a' = 2a + b, b' = 3b, c' = c where a, b, and c
+                are the lattice vectors of the original structure. 
         """
         self._original_structure = structure
         old_lattice = structure.lattice
